@@ -4,13 +4,14 @@ from .SharePointListItem import SharePointListItem, SharepointSiteCase
 from typing import List
 import json
 
+
 class SharePointList:
     '''
     '''
 
-    settings = {}
+    settings = None
     _items = None
-    sharepoint_site = ""
+    sharepoint_site = None
     SPItem = SharePointListItem
 
     CHANGE_DETECTED = False
@@ -20,11 +21,11 @@ class SharePointList:
     def __init__(self, sharepoint_site, settings: dict = None, items: List[SPItem] = None):
         self.sharepoint_site = sharepoint_site
         self.settings = settings
-        self._items = items
+        self.append_items(items)
 
     def __str__(self):
         items = ''
-        for _item in self.all_items:
+        for _, _item in self.all_items.items():
             items = items+str(_item.Title)+'\n'
         return items
 
@@ -35,14 +36,23 @@ class SharePointList:
             self.save_as_json(self.JSON_FILENAME)
 
     @property
-    def all_items(self) -> List[SPItem]:
+    def all_items(self):
         '''
             Get list of all SharePointListItem objects
         '''
         if self._items is None:
-            self._items = []
+            self._items = {}
         return self._items
 
+    @property
+    def list_all_items(self) -> List[SPItem]:
+        '''
+            Get list of all SharePointListItem objects
+        '''
+        if self._items is None:
+            self._items = {}
+        return list(self._items.values())
+
     @property
     def Title(self) -> str:
         return self.settings['Title']
@@ -52,40 +62,42 @@ class SharePointList:
         return self.settings['Id']
 
     def append_items(self, items):
+        if self._items is None:
+            self._items = {}
 
         if isinstance(items, list):
             for item in items:
                 item._list = self
-            _items = self.all_items.extend(items)
-            self.CHANGE_DETECTED = True
+                self._items[item.Id] = item
+
         elif isinstance(items, self.SPItem):
             items._list = self
-            _items = self.all_items.append(items)
-            self.CHANGE_DETECTED = True
+            self.all_items[items.Id] = items
 
     def get_item_by_name(self, name):
         '''
         '''
-        for item in self.all_items:
-            if name ==item.Title:
-                return item
-        return None
+        items = {}
+        for item_id, item in self._items.items():
+            if name == item.Title:
+                items[item_id] = item
+        return items
 
     def get_item_by_id(self, id):
         '''
         '''
-        for item in self._items:
-            if id ==item.Id:
-                return item
-        return None
+        if id in self._items:
+            return self._items[id]
+        else:
+            return None
 
     def get_items_by_assigned_id(self, id) -> List[SPItem]:
         '''
         '''
-        items = []
-        for item in self._items:
+        items = {}
+        for item_id, item in self._items.items():
             if id == item.ResponsibleId:
-                items.append(item)
+                items[item_id] = item
         return items
 
     def save_as_json(self, file_name):
@@ -94,17 +106,16 @@ class SharePointList:
             'sharepoint_site': self.sharepoint_site,
             'GUID': self.guid,
             'Settings': self.settings,
-            "cases": [{'settings': case.settings, 'versions': case._versions} for case in self.all_items]
-            }
+            "cases": [{'settings': case.settings, 'versions': case._versions} for _, case in self.all_items.items()]
+        }
 
         with open(file_name, 'w') as fp:
             json.dump(out_dict, fp)
-        
-        self.CHANGE_DETECTED = False
 
 
 class CasesList(SharePointList):
     SPItem = SharepointSiteCase
 
+
 class TimeRegistrationList(SharePointList):
     SPItem = TimeRegistration
